# Generated by Django 2.2.12 on 2020-06-01 10:02

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("wagtaildonate", "0029_rename_donation_model_to_single_donation"),
    ]

    operations = [
        migrations.AddField(
            model_name="payin",
            name="address_line_3",
            field=models.CharField(
                blank=True, max_length=255, verbose_name="Address line 3"
            ),
        ),
        migrations.AddField(
            model_name="recurringdonation",
            name="address_line_3",
            field=models.CharField(
                blank=True, max_length=255, verbose_name="Address line 3"
            ),
        ),
        migrations.AddField(
            model_name="singledonation",
            name="address_line_3",
            field=models.CharField(
                blank=True, max_length=255, verbose_name="Address line 3"
            ),
        ),
    ]
