# Generated by Django 2.2.11 on 2020-03-13 11:06

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("wagtaildonate", "0008_donation_giftaid_organisation"),
    ]

    operations = [
        migrations.AddField(
            model_name="donation",
            name="in_memory_of",
            field=models.CharField(
                blank=True, default="", max_length=60, verbose_name="In memory of"
            ),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="donation",
            name="in_memory",
            field=models.BooleanField(default=False, verbose_name="In memory"),
            preserve_default=False,
        ),
    ]
