# Generated by Django 2.2.12 on 2020-05-29 20:25

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("wagtailcore", "0045_assign_unlock_grouppagepermission"),
        ("wagtaildonate", "0028_payin"),
    ]

    operations = [
        migrations.RenameModel(old_name="Donation", new_name="SingleDonation"),
    ]
