# Generated by Django 2.2.11 on 2020-03-11 11:16

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("wagtaildonate", "0007_country"),
    ]

    operations = [
        migrations.AddField(
            model_name="donation",
            name="gift_aid_declaration",
            field=models.BooleanField(default=False, verbose_name="Gift Aid"),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="donation",
            name="on_behalf_of_organisation",
            field=models.BooleanField(
                default=False, verbose_name="On behalf of organisation"
            ),
            preserve_default=False,
        ),
    ]
