# Generated by Django 2.2.12 on 2020-08-25 13:57

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("wagtaildonate", "0031_remove_conrete_models"),
    ]

    operations = [
        migrations.CreateModel(
            name="PayInEvent",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("event_code", models.CharField(max_length=50, unique=True)),
                ("event_name", models.CharField(max_length=255)),
                ("fundraiser_reference_required", models.BooleanField()),
            ],
            options={
                "verbose_name": "Pay In Event",
                "verbose_name_plural": "Pay In Events",
                "abstract": False,
            },
        ),
        migrations.AddField(
            model_name="payin",
            name="event_code",
            field=models.CharField(blank=True, max_length=50),
        ),
        migrations.AddField(
            model_name="payin",
            name="event_name",
            field=models.CharField(blank=True, max_length=255),
        ),
        migrations.AddField(
            model_name="payin",
            name="fundraiser_reference",
            field=models.CharField(blank=True, max_length=50),
        ),
    ]
