# Generated by Django 2.2.7 on 2020-02-28 11:52

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("wagtaildonate", "0003_donation"),
    ]

    operations = [
        migrations.AddField(
            model_name="donationcampaignpage",
            name="thank_you_strapline",
            field=models.TextField(blank=True),
        ),
        migrations.AddField(
            model_name="donationfundraisingpayinpage",
            name="thank_you_strapline",
            field=models.TextField(blank=True),
        ),
        migrations.AddField(
            model_name="donationpage",
            name="thank_you_strapline",
            field=models.TextField(blank=True),
        ),
        migrations.AlterField(
            model_name="donationcampaignpage",
            name="default_donation_frequency",
            field=models.CharField(
                choices=[("single", "single"), ("regular", "regular")],
                default="single",
                help_text="Default donation frequency to prompt the user with. Only applies if both single and regular donations are allowed.",
                max_length=20,
            ),
        ),
        migrations.AlterField(
            model_name="donationpage",
            name="default_donation_frequency",
            field=models.CharField(
                choices=[("single", "single"), ("regular", "regular")],
                default="single",
                help_text="Default donation frequency to prompt the user with. Only applies if both single and regular donations are allowed.",
                max_length=20,
            ),
        ),
    ]
