# Generated by Django 2.2.7 on 2020-03-26 15:45

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("wagtaildonate", "0009_donation_memory"),
    ]

    operations = [
        migrations.AddField(
            model_name="donation",
            name="payment_method",
            field=models.CharField(default="", max_length=100),
            preserve_default=False,
        ),
    ]
