# Generated by Django 2.2.12 on 2020-05-27 10:22

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("wagtaildonate", "0024_donationexportlog_default_permissions"),
    ]

    operations = [
        migrations.AddField(
            model_name="donationexportlog",
            name="remote_addr",
            field=models.CharField(
                blank=True, max_length=255, verbose_name="REMOTE_ADDR"
            ),
        ),
        migrations.AddField(
            model_name="donationexportlog",
            name="remote_host",
            field=models.CharField(
                blank=True, max_length=255, verbose_name="REMOTE_HOST"
            ),
        ),
        migrations.AddField(
            model_name="donationexportlog",
            name="user_agent",
            field=models.CharField(blank=True, max_length=255),
        ),
        migrations.AddField(
            model_name="donationexportlog",
            name="x_forwarded_for",
            field=models.CharField(
                blank=True, max_length=255, verbose_name="X-Forwarded-For"
            ),
        ),
    ]
