# Generated by Django 2.2.11 on 2020-04-09 10:40

from django.db import migrations, models
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        ("wagtaildonate", "0013_donation_export_log"),
    ]

    operations = [
        migrations.AddField(
            model_name="donation",
            name="created_at",
            field=models.DateTimeField(
                auto_now_add=True,
                default=django.utils.timezone.now,
                verbose_name="Created at",
            ),
            preserve_default=False,
        ),
    ]
