# Generated by Django 2.2.12 on 2020-05-22 01:19

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("wagtaildonate", "0022_thank_you_page_content"),
    ]

    operations = [
        migrations.AddField(
            model_name="donation",
            name="email_consent",
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name="donation",
            name="phone_consent",
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name="donation",
            name="post_consent",
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name="donation",
            name="sms_consent",
            field=models.BooleanField(
                blank=True, default=None, null=True, verbose_name="SMS consent"
            ),
        ),
        migrations.AddField(
            model_name="recurringdonation",
            name="email_consent",
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name="recurringdonation",
            name="phone_consent",
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name="recurringdonation",
            name="post_consent",
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name="recurringdonation",
            name="sms_consent",
            field=models.BooleanField(
                blank=True, default=None, null=True, verbose_name="SMS consent"
            ),
        ),
    ]
