# Generated by Django 2.2.12 on 2020-05-28 01:37

from django.db import migrations

from wagtail import fields as wagtail_fields

import wagtaildonate.models.pages


class Migration(migrations.Migration):
    dependencies = [
        ("wagtaildonate", "0025_donationexportlog_user_info"),
    ]

    operations = [
        migrations.AlterField(
            model_name="donationcampaignpage",
            name="thank_you_email_content",
            field=wagtail_fields.StreamField(
                [("paragraph", wagtaildonate.models.pages.EmailParagraphBlock())],
                blank=True,
            ),
        ),
        migrations.AlterField(
            model_name="donationfundraisingpayinpage",
            name="thank_you_email_content",
            field=wagtail_fields.StreamField(
                [("paragraph", wagtaildonate.models.pages.EmailParagraphBlock())],
                blank=True,
            ),
        ),
        migrations.AlterField(
            model_name="donationpage",
            name="thank_you_email_content",
            field=wagtail_fields.StreamField(
                [("paragraph", wagtaildonate.models.pages.EmailParagraphBlock())],
                blank=True,
            ),
        ),
    ]
