# Generated by Django 2.2.11 on 2020-03-30 12:46

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("wagtaildonate", "0011_donation_rename_address_lines"),
    ]

    operations = [
        migrations.AddField(
            model_name="donation",
            name="provider_transaction_status",
            field=models.CharField(default="", max_length=100, blank=True),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name="donation",
            name="transaction_status",
            field=models.CharField(
                choices=[
                    ("settling", "Settling"),
                    ("settled", "Settled"),
                    ("failed", "Failed"),
                    ("unknown", "Unknown"),
                ],
                max_length=100,
            ),
        ),
    ]
