# Generated by Django 2.2.23 on 2021-06-16 14:27

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("wagtaildonate", "0032_payin_events"),
    ]

    operations = [
        migrations.AddField(
            model_name="payin",
            name="liability_shift_possible",
            field=models.BooleanField(blank=True, default=False),
        ),
        migrations.AddField(
            model_name="payin",
            name="liability_shifted",
            field=models.BooleanField(blank=True, default=False),
        ),
        migrations.AddField(
            model_name="payin",
            name="three_d_secure_status",
            field=models.CharField(blank=True, default="", max_length=100),
        ),
        migrations.AddField(
            model_name="singledonation",
            name="liability_shift_possible",
            field=models.BooleanField(blank=True, default=False),
        ),
        migrations.AddField(
            model_name="singledonation",
            name="liability_shifted",
            field=models.BooleanField(blank=True, default=False),
        ),
        migrations.AddField(
            model_name="singledonation",
            name="three_d_secure_status",
            field=models.CharField(blank=True, default="", max_length=100),
        ),
    ]
