# Generated by Django 2.2.7 on 2020-03-04 10:43

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("wagtaildonate", "0005_add_contact_details_fields"),
    ]

    operations = [
        migrations.AddField(
            model_name="donation",
            name="amount",
            field=models.DecimalField(decimal_places=2, default=0.0, max_digits=10),
            preserve_default=False,
        ),
    ]
