# Generated by Django 2.2.7 on 2020-02-21 11:59

import django.db.models.deletion
from django.db import migrations, models

from wagtail.images import get_image_model_string

image_model = get_image_model_string()


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(get_image_model_string()),
        ("wagtaildonate", "0001_initial"),
    ]

    operations = [
        migrations.AddField(
            model_name="donationfundraisingpayinpage",
            name="hero_image",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="+",
                to=image_model,
            ),
        ),
        migrations.AddField(
            model_name="donationfundraisingpayinpage",
            name="hero_summary_text",
            field=models.TextField(blank=True),
        ),
        migrations.AddField(
            model_name="donationfundraisingpayinpage",
            name="introduction",
            field=models.TextField(blank=True),
        ),
    ]
