# Generated by Django 3.2.12 on 2022-05-12 08:25

from django.db import migrations


from wagtail import blocks as wagtail_blocks
from wagtail import fields as wagtail_fields


class Migration(migrations.Migration):
    dependencies = [
        ("wagtaildonate", "0033_three_d_secure_fields"),
    ]

    operations = [
        migrations.AlterField(
            model_name="thankyouctasnippet",
            name="link",
            field=wagtail_fields.StreamField(
                [
                    (
                        "external_link",
                        wagtail_blocks.StructBlock(
                            [
                                ("url", wagtail_blocks.URLBlock()),
                                ("title", wagtail_blocks.CharBlock()),
                            ],
                            icon="link",
                        ),
                    ),
                    (
                        "internal_link",
                        wagtail_blocks.StructBlock(
                            [
                                ("page", wagtail_blocks.PageChooserBlock()),
                                ("title", wagtail_blocks.CharBlock(required=False)),
                            ],
                            icon="link",
                        ),
                    ),
                ],
                blank=True,
                use_json_field=True,
            ),
        ),
    ]
