# Generated by Django 2.2.12 on 2020-04-24 15:07

from django.db import migrations, models
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        ("wagtaildonate", "0018_phonenumber_not_mandatory"),
    ]

    operations = [
        migrations.AlterField(
            model_name="donation",
            name="created_at",
            field=models.DateTimeField(
                default=django.utils.timezone.now, verbose_name="Created at"
            ),
        ),
        migrations.AlterField(
            model_name="donationexportlog",
            name="created_at",
            field=models.DateTimeField(default=django.utils.timezone.now),
        ),
        migrations.AlterField(
            model_name="recurringdonation",
            name="created_at",
            field=models.DateTimeField(
                default=django.utils.timezone.now, verbose_name="Created at"
            ),
        ),
    ]
