# Generated by Django 2.2.12 on 2020-05-07 16:39

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("wagtaildonate", "0019_create_at_to_use_default_timezone_now"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="donation",
            options={
                "permissions": (
                    ("can_export_donations", "Can export donate transactions"),
                ),
                "verbose_name": "Donation",
                "verbose_name_plural": "Donations",
            },
        ),
        migrations.AlterModelOptions(
            name="recurringdonation",
            options={
                "permissions": (
                    (
                        "can_export_recurring_donations",
                        "Can export recurring donate transactions",
                    ),
                ),
                "verbose_name": "Recurring Donation",
                "verbose_name_plural": "Recurring Donations",
            },
        ),
    ]
