# Generated by Django 2.2.12 on 2020-06-01 17:10

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("wagtailcore", "0045_assign_unlock_grouppagepermission"),
        ("wagtaildonate", "0030_addressline3"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="donationfundraisingpayinpage", name="hero_image"
        ),
        migrations.RemoveField(
            model_name="donationfundraisingpayinpage", name="page_ptr"
        ),
        migrations.RemoveField(model_name="donationpage", name="checkout_hero_image"),
        migrations.RemoveField(model_name="donationpage", name="hero_image"),
        migrations.RemoveField(model_name="donationpage", name="page_ptr"),
        migrations.RemoveField(
            model_name="suggesteddonationcampaignpageplacementregular", name="page"
        ),
        migrations.RemoveField(
            model_name="suggesteddonationcampaignpageplacementsingle", name="page"
        ),
        migrations.RemoveField(
            model_name="suggesteddonationdonatepageplacementregular", name="page"
        ),
        migrations.RemoveField(
            model_name="suggesteddonationdonatepageplacementsingle", name="page"
        ),
        migrations.DeleteModel(name="DonationCampaignPage"),
        migrations.DeleteModel(name="DonationFundraisingPayInPage"),
        migrations.DeleteModel(name="DonationPage"),
        migrations.DeleteModel(name="SuggestedDonationCampaignPagePlacementRegular"),
        migrations.DeleteModel(name="SuggestedDonationCampaignPagePlacementSingle"),
        migrations.DeleteModel(name="SuggestedDonationDonatePagePlacementRegular"),
        migrations.DeleteModel(name="SuggestedDonationDonatePagePlacementSingle"),
    ]
