# Generated by Django 2.2.12 on 2020-05-29 08:39

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("wagtaildonate", "0026_thankyouemailcontent_not_mandatory"),
    ]

    operations = [
        migrations.AlterField(
            model_name="donationcampaignpage",
            name="thank_you_email_subject",
            field=models.CharField(blank=True, max_length=255),
        ),
        migrations.AlterField(
            model_name="donationfundraisingpayinpage",
            name="thank_you_email_subject",
            field=models.CharField(blank=True, max_length=255),
        ),
        migrations.AlterField(
            model_name="donationpage",
            name="thank_you_email_subject",
            field=models.CharField(blank=True, max_length=255),
        ),
    ]
