# Generated by Django 2.2.7 on 2020-03-10 05:13

from django.db import migrations, models

from wagtaildonate.countries import country_choices


class Migration(migrations.Migration):

    dependencies = [
        ("wagtaildonate", "0006_donation_amount"),
    ]

    operations = [
        migrations.AlterField(
            model_name="donation",
            name="country",
            field=models.CharField(
                choices=country_choices(), max_length=255, verbose_name="Country"
            ),
        ),
    ]
