# Generated by Django 2.2.12 on 2020-04-24 12:16

from django.db import migrations, models
import phonenumber_field.modelfields


class Migration(migrations.Migration):

    dependencies = [
        ("wagtaildonate", "0017_donation_donation_page"),
    ]

    operations = [
        migrations.AlterField(
            model_name="donation",
            name="email",
            field=models.EmailField(
                blank=True, max_length=255, verbose_name="Email address"
            ),
        ),
        migrations.AlterField(
            model_name="donation",
            name="phone_number",
            field=phonenumber_field.modelfields.PhoneNumberField(
                blank=True, max_length=128, region=None, verbose_name="Phone number"
            ),
        ),
        migrations.AlterField(
            model_name="recurringdonation",
            name="email",
            field=models.EmailField(
                blank=True, max_length=255, verbose_name="Email address"
            ),
        ),
        migrations.AlterField(
            model_name="recurringdonation",
            name="phone_number",
            field=phonenumber_field.modelfields.PhoneNumberField(
                blank=True, max_length=128, region=None, verbose_name="Phone number"
            ),
        ),
    ]
