# Generated by Django 2.2.11 on 2020-04-09 14:37

from django.db import migrations, models

from wagtail import fields as wagtail_fields

import wagtaildonate.models.pages


class Migration(migrations.Migration):

    dependencies = [
        ("wagtaildonate", "0015_recurringdonation"),
    ]

    operations = [
        migrations.AddField(
            model_name="donationcampaignpage",
            name="thank_you_email_content",
            field=wagtail_fields.StreamField(
                [("paragraph", wagtaildonate.models.pages.EmailParagraphBlock())],
                default="",
            ),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="donationcampaignpage",
            name="thank_you_email_subject",
            field=models.CharField(default="", max_length=255),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="donationfundraisingpayinpage",
            name="thank_you_email_content",
            field=wagtail_fields.StreamField(
                [("paragraph", wagtaildonate.models.pages.EmailParagraphBlock())],
                default="",
            ),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="donationfundraisingpayinpage",
            name="thank_you_email_subject",
            field=models.CharField(default="", max_length=255),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="donationpage",
            name="thank_you_email_content",
            field=wagtail_fields.StreamField(
                [("paragraph", wagtaildonate.models.pages.EmailParagraphBlock())],
                default="",
            ),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="donationpage",
            name="thank_you_email_subject",
            field=models.CharField(default="", max_length=255),
            preserve_default=False,
        ),
    ]
