# Generated by Django 2.2.7 on 2020-03-26 15:58

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("wagtaildonate", "0010_donation_payment_method"),
    ]

    operations = [
        migrations.RenameField(
            model_name="donation", old_name="address_line1", new_name="address_line_1"
        ),
        migrations.RenameField(
            model_name="donation", old_name="address_line2", new_name="address_line_2"
        ),
    ]
