# Generated by Django 2.2.7 on 2020-02-28 11:03

from django.db import migrations, models

import phonenumber_field.modelfields


class Migration(migrations.Migration):

    dependencies = [
        ("wagtaildonate", "0004_thank_you_fields"),
    ]

    operations = [
        migrations.AddField(
            model_name="donation",
            name="address_line1",
            field=models.CharField(
                default="", max_length=255, verbose_name="Address line 1"
            ),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="donation",
            name="address_line2",
            field=models.CharField(
                blank=True, max_length=255, verbose_name="Address line 2"
            ),
        ),
        migrations.AddField(
            model_name="donation",
            name="country",
            field=models.CharField(default="", max_length=255, verbose_name="Country"),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="donation",
            name="email",
            field=models.EmailField(
                default="", max_length=255, verbose_name="Email address"
            ),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="donation",
            name="first_name",
            field=models.CharField(
                default="", max_length=100, verbose_name="First name"
            ),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="donation",
            name="phone_number",
            field=phonenumber_field.modelfields.PhoneNumberField(
                default="", max_length=128, region=None, verbose_name="Phone number"
            ),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="donation",
            name="postal_code",
            field=models.CharField(
                default="", max_length=50, verbose_name="Postal code"
            ),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="donation",
            name="surname",
            field=models.CharField(default="", max_length=100, verbose_name="Surname"),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="donation",
            name="town",
            field=models.CharField(default="", max_length=255, verbose_name="Town"),
            preserve_default=False,
        ),
    ]
