# Generated by Django 2.2.12 on 2020-05-14 09:40

from django.db import migrations, models
import django.db.models.deletion

from wagtail.images import get_image_model_string

image_model = get_image_model_string()


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(get_image_model_string()),
        ("wagtaildonate", "0020_add_export_permissions"),
    ]

    operations = [
        migrations.AddField(
            model_name="donationcampaignpage",
            name="checkout_hero_image",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="+",
                to=image_model,
            ),
        ),
        migrations.AddField(
            model_name="donationcampaignpage",
            name="checkout_hero_summary_text",
            field=models.TextField(blank=True),
        ),
        migrations.AddField(
            model_name="donationpage",
            name="checkout_hero_image",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="+",
                to=image_model,
            ),
        ),
        migrations.AddField(
            model_name="donationpage",
            name="checkout_hero_summary_text",
            field=models.TextField(blank=True),
        ),
    ]
