# Generated by Django 2.2.7 on 2020-02-24 18:23

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("wagtaildonate", "0002_add_fundraising_pay_in_fields"),
    ]

    operations = [
        migrations.CreateModel(
            name="Donation",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "transaction_id",
                    models.CharField(max_length=50, verbose_name="Transaction ID"),
                ),
                ("transaction_status", models.CharField(blank=True, max_length=100)),
            ],
            options={"verbose_name": "Donation", "verbose_name_plural": "Donations"},
        ),
    ]
